diff --git a/drivers/net/wireless/ath/ath12k/ce.c b/drivers/net/wireless/ath/ath12k/ce.c
index 740586fe49d1..5caf210ee677 100644
--- a/drivers/net/wireless/ath/ath12k/ce.c
+++ b/drivers/net/wireless/ath/ath12k/ce.c
@@ -291,6 +291,7 @@ static int ath12k_ce_rx_post_pipe(struct ath12k_ce_pipe *pipe)
 		paddr = dma_map_single(ab->dev, skb->data,
 				       skb->len + skb_tailroom(skb),
 				       DMA_FROM_DEVICE);
+		ath12k_info(ab, "dma map: ath12k_ce_rx_post_pipe: while (pipe->rx_buf_needed), paddr=0x%llx\n", paddr);
 		if (unlikely(dma_mapping_error(ab->dev, paddr))) {
 			ath12k_warn(ab, "failed to dma map ce rx buf\n");
 			dev_kfree_skb_any(skb);
diff --git a/drivers/net/wireless/ath/ath12k/dbring.c b/drivers/net/wireless/ath/ath12k/dbring.c
index 788160c84c68..3e6db22d4841 100644
--- a/drivers/net/wireless/ath/ath12k/dbring.c
+++ b/drivers/net/wireless/ath/ath12k/dbring.c
@@ -30,10 +30,13 @@ static int ath12k_dbring_bufs_replenish(struct ath12k *ar,
 	ptr_aligned = PTR_ALIGN(ptr_unaligned, ring->buf_align);
 	paddr = dma_map_single(ab->dev, ptr_aligned, ring->buf_sz,
 			       DMA_FROM_DEVICE);
+	ath12k_info(ab, "begin dma map: ath12k_dbring_bufs_replenish, paddr=0x%llx\n", paddr);
 
 	ret = dma_mapping_error(ab->dev, paddr);
-	if (ret)
+	if (ret) {
+		ath12k_warn(ab, "failed to dma map dbring buf\n");
 		goto err;
+	}
 
 	spin_lock_bh(&ring->idr_lock);
 	buf_id = idr_alloc(&ring->bufs_idr, buff, 0, ring->bufs_max, gfp);
diff --git a/drivers/net/wireless/ath/ath12k/dp_mon.c b/drivers/net/wireless/ath/ath12k/dp_mon.c
index 7bfd323cdf24..bc472c55ef05 100644
--- a/drivers/net/wireless/ath/ath12k/dp_mon.c
+++ b/drivers/net/wireless/ath/ath12k/dp_mon.c
@@ -1295,9 +1295,12 @@ int ath12k_dp_mon_buf_replenish(struct ath12k_base *ab,
 		paddr = dma_map_single(ab->dev, skb->data,
 				       skb->len + skb_tailroom(skb),
 				       DMA_FROM_DEVICE);
+		ath12k_info(ab, "dma map: ath12k_dp_mon_buf_replenish: while (req_entries > 0), paddr=0x%llx\n", paddr);
 
-		if (unlikely(dma_mapping_error(ab->dev, paddr)))
+		if (unlikely(dma_mapping_error(ab->dev, paddr))) {
+			ath12k_warn(ab, "failed to dma map dp mon buf\n");
 			goto fail_free_skb;
+		}
 
 		spin_lock_bh(&buf_ring->idr_lock);
 		buf_id = idr_alloc(&buf_ring->bufs_idr, skb, 0,
diff --git a/drivers/net/wireless/ath/ath12k/dp_rx.c b/drivers/net/wireless/ath/ath12k/dp_rx.c
index 1623298ba2c4..c9d58c3b185e 100644
--- a/drivers/net/wireless/ath/ath12k/dp_rx.c
+++ b/drivers/net/wireless/ath/ath12k/dp_rx.c
@@ -346,8 +346,11 @@ int ath12k_dp_rx_bufs_replenish(struct ath12k_base *ab,
 		paddr = dma_map_single(ab->dev, skb->data,
 				       skb->len + skb_tailroom(skb),
 				       DMA_FROM_DEVICE);
-		if (dma_mapping_error(ab->dev, paddr))
+		ath12k_info(ab, "begin dma map: ath12k_dp_rx_bufs_replenish: while (num_remain > 0), paddr=0x%llx\n", paddr);
+		if (dma_mapping_error(ab->dev, paddr)) {
+			ath12k_warn(ab, "failed to dma map skb buf\n");
 			goto fail_free_skb;
+		}
 
 		rx_desc = list_first_entry_or_null(used_list,
 						   struct ath12k_rx_desc_info,
@@ -999,9 +1002,11 @@ int ath12k_dp_rx_peer_tid_setup(struct ath12k *ar, const u8 *peer_mac, int vdev_
 
 	paddr = dma_map_single(ab->dev, addr_aligned, hw_desc_sz,
 			       DMA_BIDIRECTIONAL);
+	ath12k_info(ab, "begin dma map: ath12k_dp_rx_peer_tid_setup, paddr=0x%llx\n", paddr);
 
 	ret = dma_mapping_error(ab->dev, paddr);
 	if (ret) {
+		ath12k_warn(ab, "failed to dma map tid\n");
 		spin_unlock_bh(&ab->base_lock);
 		goto err_mem_free;
 	}
@@ -3064,8 +3069,11 @@ static int ath12k_dp_rx_h_defrag_reo_reinject(struct ath12k *ar,
 	buf_paddr = dma_map_single(ab->dev, defrag_skb->data,
 				   defrag_skb->len + skb_tailroom(defrag_skb),
 				   DMA_TO_DEVICE);
-	if (dma_mapping_error(ab->dev, buf_paddr))
+	ath12k_info(ab, "begin dma map: ath12k_dp_rx_h_defrag_reo_reinject, paddr=0x%llx\n", buf_paddr);
+	if (dma_mapping_error(ab->dev, buf_paddr)) {
+		ath12k_warn(ab, "failed to dma map reo\n");
 		return -ENOMEM;
+	}
 
 	spin_lock_bh(&dp->rx_desc_lock);
 	desc_info = list_first_entry_or_null(&dp->rx_desc_free_list,
diff --git a/drivers/net/wireless/ath/ath12k/dp_tx.c b/drivers/net/wireless/ath/ath12k/dp_tx.c
index 734e3da4cbf1..9a37670d02bc 100644
--- a/drivers/net/wireless/ath/ath12k/dp_tx.c
+++ b/drivers/net/wireless/ath/ath12k/dp_tx.c
@@ -352,6 +352,7 @@ int ath12k_dp_tx(struct ath12k *ar, struct ath12k_vif *arvif,
 	}
 map:
 	ti.paddr = dma_map_single(ab->dev, skb->data, skb->len, DMA_TO_DEVICE);
+	ath12k_info(ab, "begin dma map: ath12k_dp_tx: map, paddr=0x%llx\n", ti.paddr);
 	if (dma_mapping_error(ab->dev, ti.paddr)) {
 		atomic_inc(&ab->soc_stats.tx_err.misc_fail);
 		ath12k_warn(ab, "failed to DMA map data Tx buffer\n");
@@ -403,8 +404,10 @@ int ath12k_dp_tx(struct ath12k *ar, struct ath12k_vif *arvif,
 
 		ti.paddr = dma_map_single(ab->dev, skb_ext_desc->data,
 					  skb_ext_desc->len, DMA_TO_DEVICE);
+		ath12k_info(ab, "begin dma map: ath12k_dp_tx: if (msdu_ext_desc), paddr=0x%llx\n", ti.paddr);
 		ret = dma_mapping_error(ab->dev, ti.paddr);
 		if (ret) {
+			ath12k_warn(ab, "failed to dma map ext desc\n");
 			kfree_skb(skb_ext_desc);
 			goto fail_unmap_dma;
 		}
diff --git a/drivers/net/wireless/ath/ath12k/htc.c b/drivers/net/wireless/ath/ath12k/htc.c
index d13616bf07f4..5b7a7b4c622a 100644
--- a/drivers/net/wireless/ath/ath12k/htc.c
+++ b/drivers/net/wireless/ath/ath12k/htc.c
@@ -110,8 +110,10 @@ int ath12k_htc_send(struct ath12k_htc *htc,
 	ath12k_htc_prepare_tx_skb(ep, skb);
 
 	skb_cb->paddr = dma_map_single(dev, skb->data, skb->len, DMA_TO_DEVICE);
+	ath12k_info(ab, "begin dma map: ath12k_htc_send, paddr=0x%llx\n", skb_cb->paddr);
 	ret = dma_mapping_error(dev, skb_cb->paddr);
 	if (ret) {
+		ath12k_warn(ab, "failed to dma map htc\n");
 		ret = -EIO;
 		goto err_credits;
 	}
diff --git a/drivers/net/wireless/ath/ath12k/mac.c b/drivers/net/wireless/ath/ath12k/mac.c
index fbf5d5728357..8b313a83e8ea 100644
--- a/drivers/net/wireless/ath/ath12k/mac.c
+++ b/drivers/net/wireless/ath/ath12k/mac.c
@@ -5748,6 +5748,7 @@ static int ath12k_mac_mgmt_tx_wmi(struct ath12k *ar, struct ath12k_vif *arvif,
 	}
 
 	paddr = dma_map_single(ab->dev, skb->data, skb->len, DMA_TO_DEVICE);
+	ath12k_info(ab, "begin dma map: ath12k_mac_mgmt_tx_wmi, paddr=0x%llx\n", paddr);
 	if (dma_mapping_error(ab->dev, paddr)) {
 		ath12k_warn(ab, "failed to DMA map mgmt Tx buffer\n");
 		ret = -EIO;
